@@ -7,13 +7,16 @@ use Role::Tiny;
 use Role::Tiny::With;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-12-01'; # DATE
+our $DATE = '2024-01-16'; # DATE
 our $DIST = 'ArrayData'; # DIST
-our $VERSION = '0.2.5'; # VERSION
+our $VERSION = '0.2.6'; # VERSION
 
 # constructor
 requires 'new';
 
+# other required methods
+requires 'get_item_count';
+
 # mixin
 with 'Role::TinyCommons::Iterator::Resettable';
 with 'Role::TinyCommons::Collection::GetItemByPos';
@@ -66,7 +69,7 @@ ArrayDataRole::Spec::Basic - Required methods for all ArrayData::* modules
 
 =head1 VERSION
 
-This document describes version 0.2.5 of ArrayDataRole::Spec::Basic (from Perl distribution ArrayData), released on 2021-12-01.
+This document describes version 0.2.6 of ArrayDataRole::Spec::Basic (from Perl distribution ArrayData), released on 2024-01-16.
 
 =head1 DESCRIPTION
 
@@ -75,6 +78,24 @@ interface (L<Role::TinyCommons::Iterator::Resettable>) as well as get elements
 by position (L<Role::TinyCommons::Collection::GetItemByPos>), like what a
 regular Perl array lets you.
 
+It allows an array with infinite number of elements.
+
+ category                     method name                note                        modifies iterator?
+ --------                     -----------                -------                     ------------------
+ instantiating                new(%args)                                             N/A
+
+ iterating items              has_next_item()                                        no
+                              get_next_item()                                        yes (moves forward 1 position)
+                              reset_iterator()                                       yes (resets)
+
+ iterating items (alt)        each_item()                                            yes (resets)
+
+ getting all items            get_all_items()                                        yes (resets)
+
+ getting item count           get_item_count()                                       yes (resets) / no (for some implementations)
+
+ utility: applying roles      apply_roles(R1, R2, ...)                               N/A
+
 =head1 ROLES MIXED IN
 
 L<Role::TinyCommons::Iterator::Resettable>
@@ -107,12 +128,36 @@ From L<Role::TinyCommons::Iterator::Resettable>.
 
 From L<Role::TinyCommons::Collection::GetItemByPos>.
 
+Should reset iterator.
+
 =head2 has_item_at_pos
 
 From L<Role::TinyCommons::Collection::GetItemByPos>.
 
+Can reset iterator if required.
+
+=head2 get_item_count
+
+Provided by L<Role::TinyCommons::Collection::GetItemByPos>, but you can provide
+a more efficient implementation.
+
+Get number of elements of array. Must return -1 to mean an array with infinite
+number of elements. Can reset iterator if required.
+
 =head1 PROVIDED METHODS
 
+=head2 each_item
+
+From L<Role::TinyCommons::Collection::GetItemByPos>. But if you have an infinite
+array data, this method will loop endlessly; you can provide your own
+implementation to prevent this from happening.
+
+=head2 get_all_items
+
+From L<Role::TinyCommons::Collection::GetItemByPos>. But if you have an infinite
+array data, this method will loop and collect endlessly; you can provide your
+own implementation to prevent this from happening.
+
 =head2 apply_roles
 
 Usage:
@@ -126,7 +171,7 @@ namespace. It's a convenience shortcut for C<< Role::Tiny->apply_roles_to_object
 
 Return the object, so you can do something like this:
 
- my $obj = ArrayData::Word::ID::KBBI->new->apply_roles('FindItem::Iterator', 'PickItems::Iterator');
+ my $obj = ArrayData::Word::ID::KBBI->new->apply_roles('FindItem::Iterator', 'PickItems::RandomPos');
 
  my $obj = ArrayData::Word::ID::KBBI->new->apply_roles('BinarySearch::LinesInHandle');
 
@@ -161,13 +206,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2021 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
